utils::globalVariables(
  c(
    ".",
    "__pb_index__",
    "action",
    "assertion_type",
    "brief",
    "column",
    "extract",
    "f_pass",
    "f_passed",
    "n",
    "N",
    "notify",
    "pb_is_good_",
    "pb_step_",
    "pb_sum",
    "preconds",
    "S",
    "tbl_name_type",
    "tbl_name_type_n",
    "type",
    "value",
    "W",
    "warn",
    "x"
  )
)
